installer

package
v0.0.0-...-4402f81 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2026 License: Apache-2.0 Imports: 40 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetupWithManager

func SetupWithManager(mgr ctrl.Manager, providerProfiles []providerimages.ProviderImageManifests, additionalSources ...source.Source) error

SetupWithManager creates the boxcutter dependencies and sets up the installer controller with the Manager. Additional sources may be provided to trigger reconciliation from external events (e.g. a channel source for testing).

Types

type InstallerController

type InstallerController struct {
	// contains filtered or unexported fields
}

InstallerController reconciles ClusterAPI revisions, using boxcutter to apply and manage the lifecycle of CAPI provider components on the cluster.

func (*InstallerController) Reconcile

func (c *InstallerController) Reconcile(ctx context.Context, _ ctrl.Request) (ctrl.Result, error)

Reconcile handles applying and managing revisions on the cluster.

Jump to