Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetupWithManager ¶
func SetupWithManager(mgr ctrl.Manager, providerProfiles []providerimages.ProviderImageManifests, additionalSources ...source.Source) error
SetupWithManager creates the boxcutter dependencies and sets up the installer controller with the Manager. Additional sources may be provided to trigger reconciliation from external events (e.g. a channel source for testing).
Types ¶
type InstallerController ¶
type InstallerController struct {
// contains filtered or unexported fields
}
InstallerController reconciles ClusterAPI revisions, using boxcutter to apply and manage the lifecycle of CAPI provider components on the cluster.
Click to show internal directories.
Click to hide internal directories.